@@ -7,7 +7,7 @@ BEGIN {
 }
 
 
-our $VERSION =  '0.01_03';
+our $VERSION =  '0.01_04';
 
 =head1 NAME
 
@@ -570,6 +570,8 @@ BEGIN { # Initialization goes here
 			# Keep list of $filenames we perhaps manipulate traps
 			$DB::_tfiles->{ $filename } =  1;
 
+			*dbline =  $main::{ "_<$filename" }; #WORKAOUND (see commit)
+
 			return \%{ "::_<$filename" };
 		}
 
@@ -961,7 +963,7 @@ sub DB {
 			# Run all actions
 			for my $action ( @{ $trap->{ action } } ) {
 				# NOTICE: if we do not use scall the $DB::file:$DB::line is broken
-				$ext_call++; scall( \&process, $action );
+				$ext_call++; scall( \&process, $action, 1 );
 			}
 
 			# Actions do not stop execution
@@ -1064,7 +1066,7 @@ sub init {
 
 # Get a string and process it.
 sub process {
-	my( $str ) =  @_;
+	my( $str, $quiet ) =  @_;
 
 	my @args =  ( $DB::dbg, $str );
 	my $code =  $DB::dbg->can( 'process' );
@@ -1090,9 +1092,10 @@ sub process {
 	# in __FILE__:__LINE__ context of script we are debugging
 	print $DB::OUT "No command found. Evaluating '$str'...\n"   if $DB::options{ ddd };
 	my @result =  map{ $_ // $DB::options{ undef } } DB::eval( $str );
+	@result =  ()   if $@  &&  $result[0] eq $DB::options{ undef }; #WORKAOUND (see commit)
 
 	local $" =  $DB::options{ '"' }  //  $";
-	print $DB::OUT "@result\n";
+	print $DB::OUT "@result\n"   unless $quiet;
 	print $DB::OUT "ERROR: $@"   if $@;
 
 	# WORKAROUND: https://rt.cpan.org/Public/Bug/Display.html?id=110847
